#
# spec file for package kamerka
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kamerka
Version:        0.20
Release:        bp154.2.34
Summary:        Take photographs with a webcam and an animated interface
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://github.com/dos1/kamerka
Source:         https://github.com/dos1/kamerka/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE kamerka-suse-qimageblitz.patch sor.alexei@meowr.ru
Patch0:         kamerka-suse-qimageblitz.patch
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Declarative)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KDELibs4Support)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(Phonon4Qt5)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Script)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(libv4lconvert)
BuildRequires:  pkgconfig(qimageblitz5)
Requires:       phonon4qt5-backend
Recommends:     %{name}-lang

%description
Kamerka is a Qt5 application using KF5 libraries. It uses
Video4Linux to get an image from the webcam and is able to save
photographs. The interface is based on QML and uses its
possibilities to show an animated UI.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%{kf5_post_install}

%find_lang %{name}

%files
%license COPYING
%doc AUTHORS README
%dir %{_kf5_appsdir}/kamerka/
%{_kf5_applicationsdir}/kamerka.desktop
%{_kf5_appsdir}/kamerka/camera_click.ogg
%{_kf5_appsdir}/kamerka/timer.ogg
%{_kf5_bindir}/kamerka
%{_kf5_configkcfgdir}/kamerka.kcfg
%{_kf5_mandir}/man1/kamerka.1%{?ext_man}
%{_kf5_notifydir}/kamerka.notifyrc
%{_kf5_prefix}/share/pixmaps/kamerka.png

%files lang -f %{name}.lang

%changelog
* Wed May 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
- Update URL
* Mon May 27 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.20
  * Update translations
- Drop the _service file
* Fri May 25 2018 christophe@krop.fr
- Run spec-cleaner.
* Tue Jan 23 2018 jengelh@inai.de
- Trim bias from description.
* Mon Jan  8 2018 sor.alexei@meowr.ru
- Update to version 0.12+git20161002 (changes since 0.8.5):
  * Add several more effects.
  * Pretty buttons with icons, tooltips on buttons with icons
  * Add implode and explode effects, a qimageblits dependency to
    get more effects.
  * Use the qimageblitz library for more effects; it seems to be
    able to use some cpu optimisation pure QImage isn't.
  * Change button labels to icons.
  * Replace the "mono" effect with histogram equalisation.
  * Add a configuration option for contrast enhancement.
  * UI tweaks for buttons.
  * Better scaling of toolbar buttons
  * Fix compiler and QML runtime warnings.
  * Move effect processing into the capture thread. This fixes
    unresponsiveness of the whole UI when using CPU-intensive
    effects (like emboss or oil paint) with large resolution.
  * Fix tabs.
  * Add burst mode; Add Capture Group in settings with setting for
    Timer timeout, Burst shot number of pictures and burst shot
    delay.
  * Image controls in the settings dialogue: Brightness, contrast,
    saturation and hue.
  * Fix sound files lookup.
  * Port to Qt5/KF5.
  * Fix DropShadows.
  * qml: Use pointSize instead of pixelSize for fonts.
  * config: Flip defaults for normalization and aspect ratio lock.
  * Wait 3 frames before taking the photograph. Useful on laptops,
    so the white screen can work like a flash.
  * Don't group photo notifications.
  * qml Button: Change cursor shape when hovered.
  * Streamline notification buttons.
  * Add an ability to open the photo by clicking on the preview.
  * Use QDesktopServices instead of xdg-open directly for
    "Open directory" button.
  * Prevent previews being clicked when hidden.
  * Update translations.
- Add kamerka-suse-qimageblitz.patch.
- Add a phonon backend requirement.
* Tue Dec 25 2012 mlin@suse.com
- Update to version 0.8.5
  * Added few basic filters and mirroring support
  * Added option for locking image preview proportions
  * Fix initial window size being hardcoded to 640x480
  * Coding convention fixes
  * Added Portuguese translation, Traditional Chinese translation and
    Dutch translation
* Mon May 14 2012 mlin@suse.com
- Use %%{_kde4_sharedir}/config.kcfg instead of %%{_kde4_configkcfgdir} for
  fix compilation on openSUSE <= 11.4
* Fri Apr 20 2012 mlin@suse.com
- initial import from 0.8.1
